function [residual, g1, g2, g3] = anal_model_solution_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 10, 1);

%
% Model equations
%

lhs =0;
rhs =y(2)-y(1)-(params(13)+params(14))*y(6)+params(14)*y(6);
residual(1)= lhs-rhs;
lhs =y(6)+params(21)/params(27)*y(7)+y(1)*(1+params(26));
rhs =(1+params(26))*(y(2)+y(6))+params(24)/params(27)*y(10);
residual(2)= lhs-rhs;
lhs =y(7);
rhs =y(7)*params(28)+y(6)*(1-params(28))*params(25)/params(21)*params(5)+y(8);
residual(3)= lhs-rhs;
lhs =y(2);
rhs =y(2)*params(3)+y(1)*(1-params(3))*params(4)+y(9);
residual(4)= lhs-rhs;
lhs =y(3);
rhs =y(1);
residual(5)= lhs-rhs;
lhs =y(5);
rhs =y(6)*(-params(13));
residual(6)= lhs-rhs;
lhs =y(4);
rhs =y(2)+y(5);
residual(7)= lhs-rhs;
lhs =y(8);
rhs =y(8)*params(15)+x(1);
residual(8)= lhs-rhs;
lhs =y(9);
rhs =y(9)*params(16)+x(2);
residual(9)= lhs-rhs;
lhs =y(10);
rhs =y(10)*params(17)+x(3);
residual(10)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(10, 10);

  %
  % Jacobian matrix
  %

  g1(1,1)=1;
  g1(1,2)=(-1);
  g1(1,6)=(-(params(14)+(-(params(13)+params(14)))));
  g1(2,1)=1+params(26);
  g1(2,2)=(-(1+params(26)));
  g1(2,6)=1-(1+params(26));
  g1(2,7)=params(21)/params(27);
  g1(2,10)=(-(params(24)/params(27)));
  g1(3,6)=(-((1-params(28))*params(25)/params(21)*params(5)));
  g1(3,7)=1-params(28);
  g1(3,8)=(-1);
  g1(4,1)=(-((1-params(3))*params(4)));
  g1(4,2)=1-params(3);
  g1(4,9)=(-1);
  g1(5,1)=(-1);
  g1(5,3)=1;
  g1(6,5)=1;
  g1(6,6)=params(13);
  g1(7,2)=(-1);
  g1(7,4)=1;
  g1(7,5)=(-1);
  g1(8,8)=1-params(15);
  g1(9,9)=1-params(16);
  g1(10,10)=1-params(17);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],10,100);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],10,1000);
end
end
end
end
