%% Figures 

[bl_regcoefs] = csvread('betas_se.csv',1);
periods = 180; 

%%%% Figure 1, panel a
figure
bl_std = bl_regcoefs(:,2)*z_crit;
hold on 
plot(1:periods, bl_regcoefs(:,1),'LineWidth',2.5)
shadedErrorBar((1:periods),bl_regcoefs(:,1),bl_std);
plot(1:periods,zeros(periods,1),'k:','LineWidth',1.5)
plot(1:periods,bl_regcoefs(:,1),'b','LineWidth',2.5)
hold off
xlabel('Horizon (Months)','FontSize',12)
ylabel('$\hat{\beta} _{k}$','FontSize',12,'interpreter','latex')
%title('Regression Estimates')
xlim([0 periods])
ylim([-1.5 1.1])
hold on
scatter( 1, bl_regcoefs(1,1), 'r','fill')
hold off
h = legend('$\hat{\beta} _{k}$','95$\%$ CI');
set(h,'FontSize',12,'interpreter','latex')

%%%% Figure 1, panel b
figure
hold on 
plot(1:periods,bl_regcoefs(:,1),'k','LineWidth',3)
plot(1:periods,zeros(periods,1),'k:','LineWidth',1.5)
plot(1:periods,bl_prof_76,'LineWidth',1)
plot(1:periods,bl_regcoefs(:,1),'k','LineWidth',3)
hold off
xlabel('Horizon (Months)','FontSize',12)
ylabel('$\hat{\beta} _{k}$','FontSize',12,'interpreter','latex')


%%%% Figure 2 

%%% Cumulative FX change

gammak = NaN(periods, 1); 
gammak(1) = bl_regcoefs(1,5); 

rhoi_cum = NaN(periods,1); 
rhoi_cum(1) = bl_regcoefs(1,7); 
for i = 2:periods
   
    gammak(i) = gammak(i-1) + bl_regcoefs(i,5);
    rhoi_cum(i) = rhoi_cum(i-1) + bl_regcoefs(i,7); 
end


figure
hold on 
bsj_std = bl_regcoefs(:,4)*z_crit; 
plot(1:periods,gammak,1:periods, rhoi_cum,'r-.','LineWidth',2.5,'MarkerSize',1.5);
plot(1:periods,zeros(periods,1),'--','LineWidth',2.5,'Color',[0,0,0])
shadedErrorBar((1:periods),gammak,bsj_std);
plot(1:periods,gammak,'b',1:periods, rhoi_cum,'r-.','LineWidth',2.5,'MarkerSize',1.5);
plot(1:periods,zeros(periods,1),'--','LineWidth',2.5,'Color',[0,0,0])
h = legend('$\hat{\gamma}_k$', '$\Sigma_{h=0}^{k-1} \hat{\rho}_{h}$','Random Walk','Location','NorthWest');
set(h,'FontSize',11,'interpreter','latex')
hold off
xlabel('Horizon (Months)','FontSize',12)
ylabel('Cumulative Percent Change Relative to Today','FontSize',12)
xlim([0 periods])
ylim([-12 28])


%%  Figure 10
[betas_convy] = csvread('convy_betas.csv',1);

bcy_idiffBAA   = betas_convy(:,3); 
bcy_idiffAAA   = betas_convy(:,1); 
se_cy_idiffBAA = betas_convy(:,4); 
se_cy_idiffAAA = betas_convy(:,2); 

periods = 100; 
figure
se = z_crit90*se_cy_idiffBAA;
hold on 
plot(1:periods,bcy_idiffBAA,'LineWidth',2.5)
shadedErrorBar((1:periods),bcy_idiffBAA,se);
plot(1:periods,zeros(periods,1),'k:','LineWidth',1.5)
plot(1:periods,bcy_idiffBAA,'b','LineWidth',2.5)
hold off
xlabel('Horizon (Months)','FontSize',12)
ylabel('$\hat{\beta} _{k}$','FontSize',12,'interpreter','latex')
h = legend('$\beta _k ^{\widehat{ BAA - Treasury } }$','90$\%$ CI','location','northeast');
set(h,'FontSize',12,'interpreter','latex')
%ylim( [-0.008, 0.006])


periods = 100; 
figure
se = z_crit90*se_cy_idiffAAA;
hold on 
plot(1:periods,bcy_idiffAAA,'LineWidth',2.5)
shadedErrorBar((1:periods),bcy_idiffAAA,se);
plot(1:periods,zeros(periods,1),'k:','LineWidth',1.5)
plot(1:periods,bcy_idiffAAA,'b','LineWidth',2.5)
hold off
xlabel('Horizon (Months)','FontSize',12)
ylabel('$\hat{\beta} _{k}$','FontSize',12,'interpreter','latex')
h = legend('$\beta _k ^{\widehat{ AAA - Treasury } }$','90$\%$ CI','location','northeast');
set(h,'FontSize',12,'interpreter','latex')
