function [residual, g1, g2, g3] = model_solution_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(92, 1);
T15 = (1-params(1))*(1-params(1)*params(2))/params(1);
T39 = params(21)*params(41)^(1-params(11));
T42 = T39/(T39+params(20));
T52 = params(20)*params(41)^(params(11)-1);
T54 = T52/(params(21)+T52);
T94 = params(23)/params(11)*params(13)*params(37)/(params(87)*params(39));
T102 = params(23)/params(11)*params(12)/(params(87)*params(38));
T207 = params(77)/(1+params(77));
T209 = 1/params(113);
T214 = (params(113)-1)/params(113);
T224 = params(78)/(1+params(78));
T226 = 1/params(112);
T232 = (T226-T209)*y(88);
T241 = params(79)/(1+params(79));
T257 = params(117)^((-(params(113)-1))/params(113));
T261 = (params(116)*params(95))^T214;
T264 = params(119)^T214;
T274 = (params(119)/params(114))^((-(params(112)-1))/params(112));
T276 = (params(112)-1)/params(112);
T277 = params(101)^T276;
T281 = params(102)^T276;
T306 = params(81)/(1+params(81));
T319 = params(82)/(1+params(82));
T334 = params(83)/(1+params(83));
T346 = params(118)^((-(params(113)-1))/params(113));
T349 = (params(116)*params(96))^T214;
T352 = params(120)^T214;
T358 = (params(120)/params(114))^((-(params(112)-1))/params(112));
T361 = params(111)*params(103)^T276;
T366 = (1-params(111))*params(104)^T276;
T394 = params(87)*params(38)^params(11);
T405 = params(10)/(1-params(10))*params(37)^params(11);
T423 = params(12)*params(38)^(params(11)-1);
T446 = params(95)*((1+params(93))/params(34)-1);
T477 = params(96)*((1+params(94))/params(34)-1);
T514 = (1-params(10))/params(10)*params(102)/params(37);
T541 = 1/params(135);
T566 = 1/params(141);
T699 = params(84)/(params(87)*params(38));
T712 = (1-params(105))*params(8)*params(91)/(params(87)*params(38));
T731 = params(85)/(params(87)*params(39)/params(37));
T748 = (1-params(106))*params(16)*params(92)/(params(87)*params(39)/params(37));
lhs =y(25);
rhs =T15*y(35)+params(2)*y(117)+y(72);
residual(1)= lhs-rhs;
lhs =y(26);
rhs =T15*y(36)+params(2)*y(118)+y(73);
residual(2)= lhs-rhs;
lhs =y(27);
rhs =y(25)+T42*(y(37)-y(2));
residual(3)= lhs-rhs;
lhs =y(28);
rhs =y(26)-(y(37)-y(2))*T54+y(38)-y(3);
residual(4)= lhs-rhs;
lhs =y(37);
rhs =params(128)*y(44)+params(129)*y(45)+params(130)*y(46)+params(131)*y(50)+params(144)*y(76)+params(145)*y(77)+T94*y(78)-T102*y(32);
residual(5)= lhs-rhs;
lhs =y(39);
rhs =y(37)*(-T42);
residual(6)= lhs-rhs;
lhs =y(40);
rhs =y(37)*T54;
residual(7)= lhs-rhs;
lhs =y(38);
rhs =y(37)*params(22);
residual(8)= lhs-rhs;
lhs =y(27)+y(38)-y(3);
rhs =y(28)+y(29)-y(1);
residual(9)= lhs-rhs;
lhs =0;
rhs =params(3)*(y(122)-y(46))+y(126)-y(81)+y(119)+y(82)-(y(124)-y(79));
residual(10)= lhs-rhs;
lhs =0;
rhs =params(3)*(y(122)-y(46))+y(126)-y(81)+y(119)-y(41)+y(33)-(y(124)-y(79));
residual(11)= lhs-rhs;
lhs =0;
rhs =y(29)+params(3)*(y(122)-y(46))+y(126)-y(81)+y(119)-y(42)-y(121)+y(34)-(y(124)-y(79));
residual(12)= lhs-rhs;
lhs =0;
rhs =params(3)*(y(123)-y(50))+y(127)-y(83)+y(120)+y(84)-(y(125)-y(80));
residual(13)= lhs-rhs;
lhs =0;
rhs =params(3)*(y(123)-y(50))+y(127)-y(83)+y(120)-y(42)+y(85)-(y(125)-y(80));
residual(14)= lhs-rhs;
lhs =0;
rhs =y(121)+params(3)*(y(123)-y(50))+y(127)-y(83)+y(120)-y(41)-y(29)+y(86)-(y(125)-y(80));
residual(15)= lhs-rhs;
lhs =y(81)+y(46)*params(3)-y(79);
rhs =y(38)+y(83)+y(50)*params(3)-y(80);
residual(16)= lhs-rhs;
lhs =y(32);
rhs =y(46)*params(28)+(1-params(28))*y(87);
residual(17)= lhs-rhs;
lhs =y(81);
rhs =params(76)/(1+params(76))*(y(32)-y(46));
residual(18)= lhs-rhs;
lhs =y(82);
rhs =T207*(y(32)-T209*y(47)+T214*y(91)-y(87)*T214);
residual(19)= lhs-rhs;
lhs =y(33);
rhs =T224*(y(32)-T226*y(48)+T232+y(92)-y(87)*T214);
residual(20)= lhs-rhs;
lhs =y(34);
rhs =T241*(T232+y(32)-T226*y(49)-y(92)*params(111)/(1-params(111))-y(87)*T214);
residual(21)= lhs-rhs;
lhs =y(87);
rhs =T257*(y(47)*T261+y(88)*T264);
residual(22)= lhs-rhs;
lhs =y(88);
rhs =T274*(y(48)*params(111)*T277+y(49)*(1-params(111))*T281+y(92)*params(111)*params(112)/(params(112)-1)*(T277-T281));
residual(23)= lhs-rhs;
lhs =y(78);
rhs =y(50)*params(28)+(1-params(28))*y(89);
residual(24)= lhs-rhs;
lhs =y(83);
rhs =params(80)/(1+params(80))*(y(78)-y(50));
residual(25)= lhs-rhs;
lhs =y(84);
rhs =T306*(y(78)-T209*y(51)+T214*y(94)-T214*y(89));
residual(26)= lhs-rhs;
lhs =y(85);
rhs =T319*(y(78)-T226*y(52)+(T226-T209)*y(90)+T276*y(96)-T214*y(89));
residual(27)= lhs-rhs;
lhs =y(86);
rhs =T334*((T226-T209)*y(90)+y(78)-T226*y(53)+T276*y(95)-T214*y(89));
residual(28)= lhs-rhs;
lhs =y(89);
rhs =T346*(y(51)*T349+y(90)*T352);
residual(29)= lhs-rhs;
lhs =y(90);
rhs =T358*(T361*(y(52)+y(96))+T366*(y(53)+y(95)));
residual(30)= lhs-rhs;
lhs =y(35);
rhs =y(81)+y(46)*params(3)+y(44)*params(4)-(1+params(4))*y(68)-y(39)-y(79);
residual(31)= lhs-rhs;
lhs =y(36);
rhs =y(83)+y(38)+y(50)*params(3)+y(45)*params(4)-(1+params(4))*y(69)-y(40)-y(80);
residual(32)= lhs-rhs;
lhs =T394*(y(44)+params(11)*y(39));
rhs =y(46)*params(20)*params(86)+params(21)*params(86)*T405*(y(50)+params(11)*y(38))+params(21)*T405*params(89)*(y(77)+params(11)*y(38))+y(76)*params(20)*params(88)+T423*(y(32)+(params(11)-1)*y(39));
residual(33)= lhs-rhs;
lhs =params(91)*y(58)+params(84)*y(60)+y(47)*params(95)*(1-1/params(34))+T446*(y(11)-y(27))+params(95)*(1+params(93))/params(34)*y(6);
rhs =params(91)*(1+params(93))*(y(6)-y(27)+y(15))+y(76)*params(88);
residual(34)= lhs-rhs;
lhs =params(92)*y(59)+params(85)*y(61)+y(51)*params(96)*(1-1/params(34))+T477*(y(13)-y(28))+params(96)*(1+params(94))/params(34)*y(7);
rhs =params(92)*(1+params(94))*(y(7)-y(28)+y(16))+y(77)*params(89);
residual(35)= lhs-rhs;
lhs =y(47)+y(97);
rhs =y(56);
residual(36)= lhs-rhs;
lhs =y(51);
rhs =y(57);
residual(37)= lhs-rhs;
lhs =params(91)*y(58);
rhs =y(56)*params(35)+y(48)*params(101)+params(37)*params(104)*params(10)/(1-params(10))*(y(38)+y(53));
residual(38)= lhs-rhs;
lhs =params(92)*y(59);
rhs =y(57)*params(36)+T514*(y(49)-y(38))+y(52)*params(103);
residual(39)= lhs-rhs;
lhs =y(31);
rhs =y(42)+y(121)-y(29)-y(41);
residual(40)= lhs-rhs;
lhs =y(30);
rhs =y(7)+y(29)-y(1)-y(6);
residual(41)= lhs-rhs;
lhs =y(43);
rhs =y(41)-y(42);
residual(42)= lhs-rhs;
lhs =y(116);
rhs =y(29)-y(1);
residual(43)= lhs-rhs;
lhs =y(115);
rhs =y(38)-y(3);
residual(44)= lhs-rhs;
lhs =y(62);
rhs =T541*(y(79)+(1+params(4))*y(68)-y(45)*params(136)-y(50)*params(137)-y(76)*params(150)-y(77)*params(151)-y(81)-y(32)*params(123)-y(78)*params(124));
residual(45)= lhs-rhs;
lhs =y(63);
rhs =T566*(y(80)+(1+params(4))*y(69)-y(44)*params(142)-y(46)*params(143)-y(76)*params(152)-y(77)*params(153)-y(83)-y(32)*params(125)-y(78)*params(126));
residual(46)= lhs-rhs;
lhs =y(64);
rhs =y(44)-y(62);
residual(47)= lhs-rhs;
lhs =y(65);
rhs =y(45)-y(63);
residual(48)= lhs-rhs;
lhs =y(54);
rhs =y(58)-y(39)-y(44);
residual(49)= lhs-rhs;
lhs =y(55);
rhs =y(38)+y(59)-y(40)-y(45);
residual(50)= lhs-rhs;
lhs =y(101);
rhs =y(60)-y(39)-y(44);
residual(51)= lhs-rhs;
lhs =y(66);
rhs =y(54)-y(14);
residual(52)= lhs-rhs;
lhs =(params(91)-params(35))*y(67);
rhs =params(91)*y(58)-y(56)*params(35);
residual(53)= lhs-rhs;
lhs =y(111);
rhs =y(41)-y(119);
residual(54)= lhs-rhs;
lhs =y(112);
rhs =y(42)-y(120);
residual(55)= lhs-rhs;
lhs =y(100);
rhs =y(111)-y(112);
residual(56)= lhs-rhs;
lhs =y(98);
rhs =y(49)-y(39)-y(44);
residual(57)= lhs-rhs;
lhs =y(99);
rhs =y(41)-y(33);
residual(58)= lhs-rhs;
lhs =y(104);
rhs =y(42)-y(85);
residual(59)= lhs-rhs;
lhs =y(105);
rhs =y(99)-y(104);
residual(60)= lhs-rhs;
lhs =y(106);
rhs =y(44)-y(8);
residual(61)= lhs-rhs;
lhs =y(107);
rhs =y(46)-y(10);
residual(62)= lhs-rhs;
lhs =y(108);
rhs =y(45)-y(9);
residual(63)= lhs-rhs;
lhs =y(109);
rhs =y(50)-y(12);
residual(64)= lhs-rhs;
lhs =y(110);
rhs =y(58)-y(15);
residual(65)= lhs-rhs;
lhs =y(113);
rhs =y(54)-y(14);
residual(66)= lhs-rhs;
lhs =y(114);
rhs =y(47)-y(11);
residual(67)= lhs-rhs;
lhs =y(102);
rhs =y(106)-y(108);
residual(68)= lhs-rhs;
lhs =y(103);
rhs =y(107)-y(109);
residual(69)= lhs-rhs;
lhs =y(41);
rhs =y(6)*params(5)+y(27)*(1-params(5))*params(6)+y(64)*(1-params(5))*params(7)+y(70);
residual(70)= lhs-rhs;
lhs =y(42);
rhs =y(7)*params(5)+y(28)*(1-params(5))*params(14)+y(65)*(1-params(5))*params(15)+y(59)*(1-params(5))*params(109)+y(71);
residual(71)= lhs-rhs;
lhs =(y(60)-y(39)-y(44))*T699;
rhs =T699*params(105)*(y(17)-y(4)-y(8))+T712*(y(15)-y(4)-y(8))+y(44)*(1-params(105))*params(9)+y(76)*params(88)*(1-params(105))*params(107)+y(74);
residual(72)= lhs-rhs;
lhs =T731*(y(38)+y(61)-y(40)-y(45));
rhs =T731*params(106)*(y(3)+y(18)-y(5)-y(9))+T748*(y(3)+y(16)-y(5)-y(9))+y(45)*(1-params(106))*params(17)+y(77)*params(89)*(1-params(106))*params(108)+y(75);
residual(73)= lhs-rhs;
lhs =y(68);
rhs =params(42)*y(19)+params(44)*y(20)+x(it_, 1);
residual(74)= lhs-rhs;
lhs =y(69);
rhs =y(20)*params(43)+y(19)*params(44)+x(it_, 2);
residual(75)= lhs-rhs;
lhs =y(70);
rhs =params(45)*y(21)+params(47)*y(22)+x(it_, 3);
residual(76)= lhs-rhs;
lhs =y(71);
rhs =y(22)*params(46)+y(21)*params(47)+x(it_, 4);
residual(77)= lhs-rhs;
residual(78) = y(72);
residual(79) = y(73);
lhs =y(74);
rhs =params(51)*y(23)+params(53)*y(24)+x(it_, 5);
residual(80)= lhs-rhs;
lhs =y(75);
rhs =y(24)*params(52)+y(23)*params(53)+x(it_, 6);
residual(81)= lhs-rhs;
residual(82) = y(76);
residual(83) = y(77);
residual(84) = y(79);
residual(85) = y(80);
residual(86) = y(97);
residual(87) = y(91);
residual(88) = y(92);
residual(89) = y(93);
residual(90) = y(94);
residual(91) = y(95);
residual(92) = y(96);
if nargout >= 2,
  g1 = zeros(92, 133);

  %
  % Jacobian matrix
  %

T3 = (-1);
T866 = (-((-(T699*params(105)))-T712));
  g1(1,25)=1;
  g1(1,117)=(-params(2));
  g1(1,35)=(-T15);
  g1(1,72)=T3;
  g1(2,26)=1;
  g1(2,118)=(-params(2));
  g1(2,36)=(-T15);
  g1(2,73)=T3;
  g1(3,25)=T3;
  g1(3,27)=1;
  g1(3,2)=T42;
  g1(3,37)=(-T42);
  g1(4,26)=T3;
  g1(4,28)=1;
  g1(4,2)=(-T54);
  g1(4,37)=T54;
  g1(4,3)=1;
  g1(4,38)=T3;
  g1(5,32)=T102;
  g1(5,37)=1;
  g1(5,44)=(-params(128));
  g1(5,45)=(-params(129));
  g1(5,46)=(-params(130));
  g1(5,50)=(-params(131));
  g1(5,76)=(-params(144));
  g1(5,77)=(-params(145));
  g1(5,78)=(-T94);
  g1(6,37)=T42;
  g1(6,39)=1;
  g1(7,37)=(-T54);
  g1(7,40)=1;
  g1(8,37)=(-params(22));
  g1(8,38)=1;
  g1(9,27)=1;
  g1(9,28)=T3;
  g1(9,1)=1;
  g1(9,29)=T3;
  g1(9,3)=T3;
  g1(9,38)=1;
  g1(10,119)=T3;
  g1(10,46)=params(3);
  g1(10,122)=(-params(3));
  g1(10,79)=T3;
  g1(10,124)=1;
  g1(10,81)=1;
  g1(10,126)=T3;
  g1(10,82)=T3;
  g1(11,119)=T3;
  g1(11,33)=T3;
  g1(11,41)=1;
  g1(11,46)=params(3);
  g1(11,122)=(-params(3));
  g1(11,79)=T3;
  g1(11,124)=1;
  g1(11,81)=1;
  g1(11,126)=T3;
  g1(12,119)=T3;
  g1(12,29)=T3;
  g1(12,121)=1;
  g1(12,34)=T3;
  g1(12,42)=1;
  g1(12,46)=params(3);
  g1(12,122)=(-params(3));
  g1(12,79)=T3;
  g1(12,124)=1;
  g1(12,81)=1;
  g1(12,126)=T3;
  g1(13,120)=T3;
  g1(13,50)=params(3);
  g1(13,123)=(-params(3));
  g1(13,80)=T3;
  g1(13,125)=1;
  g1(13,83)=1;
  g1(13,127)=T3;
  g1(13,84)=T3;
  g1(14,120)=T3;
  g1(14,42)=1;
  g1(14,50)=params(3);
  g1(14,123)=(-params(3));
  g1(14,80)=T3;
  g1(14,125)=1;
  g1(14,83)=1;
  g1(14,127)=T3;
  g1(14,85)=T3;
  g1(15,120)=T3;
  g1(15,29)=1;
  g1(15,121)=T3;
  g1(15,41)=1;
  g1(15,50)=params(3);
  g1(15,123)=(-params(3));
  g1(15,80)=T3;
  g1(15,125)=1;
  g1(15,83)=1;
  g1(15,127)=T3;
  g1(15,86)=T3;
  g1(16,38)=T3;
  g1(16,46)=params(3);
  g1(16,50)=(-params(3));
  g1(16,79)=T3;
  g1(16,80)=1;
  g1(16,81)=1;
  g1(16,83)=T3;
  g1(17,32)=1;
  g1(17,46)=(-params(28));
  g1(17,87)=(-(1-params(28)));
  g1(18,32)=(-(params(76)/(1+params(76))));
  g1(18,46)=params(76)/(1+params(76));
  g1(18,81)=1;
  g1(19,32)=(-T207);
  g1(19,47)=(-(T207*(-T209)));
  g1(19,82)=1;
  g1(19,87)=(-(T207*(-T214)));
  g1(19,91)=(-(T207*T214));
  g1(20,32)=(-T224);
  g1(20,33)=1;
  g1(20,48)=(-(T224*(-T226)));
  g1(20,87)=(-(T224*(-T214)));
  g1(20,88)=(-(T224*(T226-T209)));
  g1(20,92)=(-T224);
  g1(21,32)=(-T241);
  g1(21,34)=1;
  g1(21,49)=(-(T241*(-T226)));
  g1(21,87)=(-(T241*(-T214)));
  g1(21,88)=(-((T226-T209)*T241));
  g1(21,92)=(-(T241*(-(params(111)/(1-params(111))))));
  g1(22,47)=(-(T257*T261));
  g1(22,87)=1;
  g1(22,88)=(-(T257*T264));
  g1(23,48)=(-(T274*params(111)*T277));
  g1(23,49)=(-(T274*(1-params(111))*T281));
  g1(23,88)=1;
  g1(23,92)=(-(T274*params(111)*params(112)/(params(112)-1)*(T277-T281)));
  g1(24,50)=(-params(28));
  g1(24,78)=1;
  g1(24,89)=(-(1-params(28)));
  g1(25,50)=params(80)/(1+params(80));
  g1(25,78)=(-(params(80)/(1+params(80))));
  g1(25,83)=1;
  g1(26,51)=(-(T306*(-T209)));
  g1(26,78)=(-T306);
  g1(26,84)=1;
  g1(26,89)=(-(T306*(-T214)));
  g1(26,94)=(-(T214*T306));
  g1(27,52)=(-(T319*(-T226)));
  g1(27,78)=(-T319);
  g1(27,85)=1;
  g1(27,89)=(-(T319*(-T214)));
  g1(27,90)=(-((T226-T209)*T319));
  g1(27,96)=(-(T276*T319));
  g1(28,53)=(-(T334*(-T226)));
  g1(28,78)=(-T334);
  g1(28,86)=1;
  g1(28,89)=(-(T334*(-T214)));
  g1(28,90)=(-((T226-T209)*T334));
  g1(28,95)=(-(T276*T334));
  g1(29,51)=(-(T346*T349));
  g1(29,89)=1;
  g1(29,90)=(-(T346*T352));
  g1(30,52)=(-(T358*T361));
  g1(30,53)=(-(T358*T366));
  g1(30,90)=1;
  g1(30,95)=(-(T358*T366));
  g1(30,96)=(-(T358*T361));
  g1(31,35)=1;
  g1(31,39)=1;
  g1(31,44)=(-params(4));
  g1(31,46)=(-params(3));
  g1(31,68)=1+params(4);
  g1(31,79)=1;
  g1(31,81)=T3;
  g1(32,36)=1;
  g1(32,38)=T3;
  g1(32,40)=1;
  g1(32,45)=(-params(4));
  g1(32,50)=(-params(3));
  g1(32,69)=1+params(4);
  g1(32,80)=1;
  g1(32,83)=T3;
  g1(33,32)=(-T423);
  g1(33,38)=(-(params(11)*params(21)*params(86)*T405+params(11)*params(21)*T405*params(89)));
  g1(33,39)=params(11)*T394-(params(11)-1)*T423;
  g1(33,44)=T394;
  g1(33,46)=(-(params(20)*params(86)));
  g1(33,50)=(-(params(21)*params(86)*T405));
  g1(33,76)=(-(params(20)*params(88)));
  g1(33,77)=(-(params(21)*T405*params(89)));
  g1(34,27)=(-T446)-(-(params(91)*(1+params(93))));
  g1(34,6)=params(95)*(1+params(93))/params(34)-params(91)*(1+params(93));
  g1(34,11)=T446;
  g1(34,47)=params(95)*(1-1/params(34));
  g1(34,15)=(-(params(91)*(1+params(93))));
  g1(34,58)=params(91);
  g1(34,60)=params(84);
  g1(34,76)=(-params(88));
  g1(35,28)=(-T477)-(-(params(92)*(1+params(94))));
  g1(35,7)=params(96)*(1+params(94))/params(34)-params(92)*(1+params(94));
  g1(35,13)=T477;
  g1(35,51)=params(96)*(1-1/params(34));
  g1(35,16)=(-(params(92)*(1+params(94))));
  g1(35,59)=params(92);
  g1(35,61)=params(85);
  g1(35,77)=(-params(89));
  g1(36,47)=1;
  g1(36,56)=T3;
  g1(36,97)=1;
  g1(37,51)=1;
  g1(37,57)=T3;
  g1(38,38)=(-(params(37)*params(104)*params(10)/(1-params(10))));
  g1(38,48)=(-params(101));
  g1(38,53)=(-(params(37)*params(104)*params(10)/(1-params(10))));
  g1(38,56)=(-params(35));
  g1(38,58)=params(91);
  g1(39,38)=T514;
  g1(39,49)=(-T514);
  g1(39,52)=(-params(103));
  g1(39,57)=(-params(36));
  g1(39,59)=params(92);
  g1(40,29)=1;
  g1(40,121)=T3;
  g1(40,31)=1;
  g1(40,41)=1;
  g1(40,42)=T3;
  g1(41,1)=1;
  g1(41,29)=T3;
  g1(41,30)=1;
  g1(41,6)=1;
  g1(41,7)=T3;
  g1(42,41)=T3;
  g1(42,42)=1;
  g1(42,43)=1;
  g1(43,1)=1;
  g1(43,29)=T3;
  g1(43,116)=1;
  g1(44,3)=1;
  g1(44,38)=T3;
  g1(44,115)=1;
  g1(45,32)=(-(T541*(-params(123))));
  g1(45,45)=(-(T541*(-params(136))));
  g1(45,50)=(-(T541*(-params(137))));
  g1(45,62)=1;
  g1(45,68)=(-((1+params(4))*T541));
  g1(45,76)=(-(T541*(-params(150))));
  g1(45,77)=(-(T541*(-params(151))));
  g1(45,78)=(-(T541*(-params(124))));
  g1(45,79)=(-T541);
  g1(45,81)=T541;
  g1(46,32)=(-(T566*(-params(125))));
  g1(46,44)=(-(T566*(-params(142))));
  g1(46,46)=(-(T566*(-params(143))));
  g1(46,63)=1;
  g1(46,69)=(-((1+params(4))*T566));
  g1(46,76)=(-(T566*(-params(152))));
  g1(46,77)=(-(T566*(-params(153))));
  g1(46,78)=(-(T566*(-params(126))));
  g1(46,80)=(-T566);
  g1(46,83)=T566;
  g1(47,44)=T3;
  g1(47,62)=1;
  g1(47,64)=1;
  g1(48,45)=T3;
  g1(48,63)=1;
  g1(48,65)=1;
  g1(49,39)=1;
  g1(49,44)=1;
  g1(49,54)=1;
  g1(49,58)=T3;
  g1(50,38)=T3;
  g1(50,40)=1;
  g1(50,45)=1;
  g1(50,55)=1;
  g1(50,59)=T3;
  g1(51,39)=1;
  g1(51,44)=1;
  g1(51,60)=T3;
  g1(51,101)=1;
  g1(52,14)=1;
  g1(52,54)=T3;
  g1(52,66)=1;
  g1(53,56)=params(35);
  g1(53,58)=(-params(91));
  g1(53,67)=params(91)-params(35);
  g1(54,119)=1;
  g1(54,41)=T3;
  g1(54,111)=1;
  g1(55,120)=1;
  g1(55,42)=T3;
  g1(55,112)=1;
  g1(56,100)=1;
  g1(56,111)=T3;
  g1(56,112)=1;
  g1(57,39)=1;
  g1(57,44)=1;
  g1(57,49)=T3;
  g1(57,98)=1;
  g1(58,33)=1;
  g1(58,41)=T3;
  g1(58,99)=1;
  g1(59,42)=T3;
  g1(59,85)=1;
  g1(59,104)=1;
  g1(60,99)=T3;
  g1(60,104)=1;
  g1(60,105)=1;
  g1(61,8)=1;
  g1(61,44)=T3;
  g1(61,106)=1;
  g1(62,10)=1;
  g1(62,46)=T3;
  g1(62,107)=1;
  g1(63,9)=1;
  g1(63,45)=T3;
  g1(63,108)=1;
  g1(64,12)=1;
  g1(64,50)=T3;
  g1(64,109)=1;
  g1(65,15)=1;
  g1(65,58)=T3;
  g1(65,110)=1;
  g1(66,14)=1;
  g1(66,54)=T3;
  g1(66,113)=1;
  g1(67,11)=1;
  g1(67,47)=T3;
  g1(67,114)=1;
  g1(68,102)=1;
  g1(68,106)=T3;
  g1(68,108)=1;
  g1(69,103)=1;
  g1(69,107)=T3;
  g1(69,109)=1;
  g1(70,27)=(-((1-params(5))*params(6)));
  g1(70,6)=(-params(5));
  g1(70,41)=1;
  g1(70,64)=(-((1-params(5))*params(7)));
  g1(70,70)=T3;
  g1(71,28)=(-((1-params(5))*params(14)));
  g1(71,7)=(-params(5));
  g1(71,42)=1;
  g1(71,59)=(-((1-params(5))*params(109)));
  g1(71,65)=(-((1-params(5))*params(15)));
  g1(71,71)=T3;
  g1(72,4)=T866;
  g1(72,39)=(-T699);
  g1(72,8)=T866;
  g1(72,44)=(-T699)-(1-params(105))*params(9);
  g1(72,15)=(-T712);
  g1(72,17)=(-(T699*params(105)));
  g1(72,60)=T699;
  g1(72,74)=T3;
  g1(72,76)=(-(params(88)*(1-params(105))*params(107)));
  g1(73,3)=(-(T731*params(106)+T748));
  g1(73,38)=T731;
  g1(73,5)=(-((-(T731*params(106)))-T748));
  g1(73,40)=(-T731);
  g1(73,9)=(-((-(T731*params(106)))-T748));
  g1(73,45)=(-T731)-(1-params(106))*params(17);
  g1(73,16)=(-T748);
  g1(73,18)=(-(T731*params(106)));
  g1(73,61)=T731;
  g1(73,75)=T3;
  g1(73,77)=(-(params(89)*(1-params(106))*params(108)));
  g1(74,19)=(-params(42));
  g1(74,68)=1;
  g1(74,20)=(-params(44));
  g1(74,128)=T3;
  g1(75,19)=(-params(44));
  g1(75,20)=(-params(43));
  g1(75,69)=1;
  g1(75,129)=T3;
  g1(76,21)=(-params(45));
  g1(76,70)=1;
  g1(76,22)=(-params(47));
  g1(76,130)=T3;
  g1(77,21)=(-params(47));
  g1(77,22)=(-params(46));
  g1(77,71)=1;
  g1(77,131)=T3;
  g1(78,72)=1;
  g1(79,73)=1;
  g1(80,23)=(-params(51));
  g1(80,74)=1;
  g1(80,24)=(-params(53));
  g1(80,132)=T3;
  g1(81,23)=(-params(53));
  g1(81,24)=(-params(52));
  g1(81,75)=1;
  g1(81,133)=T3;
  g1(82,76)=1;
  g1(83,77)=1;
  g1(84,79)=1;
  g1(85,80)=1;
  g1(86,97)=1;
  g1(87,91)=1;
  g1(88,92)=1;
  g1(89,93)=1;
  g1(90,94)=1;
  g1(91,95)=1;
  g1(92,96)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],92,17689);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],92,2352637);
end
end
end
end
